@@ -220,10 +220,15 @@ if _lib_c is None:
 # load the libudunits2 shared library
 #
 if _lib_ud is None:
-    _lib_ud = config.get_option(
+    _udunits2_c = config.get_option(
         'System', 'udunits2_path',
         default=ctypes.util.find_library('udunits2'))
-    _lib_ud = ctypes.CDLL(_lib_ud, use_errno=True)
+    if _udunits2_c:
+        _lib_ud = ctypes.CDLL(_udunits2_c, use_errno=True)
+    else:
+        msg = ('Could not find the udunits2 library "{}."'
+               ' You may need to install udunits2.').format
+        raise OSError(msg(_udunits2_c))
 
     #
     # cache common shared library functions
@@ -375,8 +380,10 @@ if not _ud_system:
         # relative to sys.prefix to support environments such as conda.
         _ud_system = _ut_read_xml(None)
         if _ud_system is None:
-            _alt_xml_path = os.path.join(sys.prefix, 'share',
-                                         'udunits', 'udunits2.xml')
+            _alt_xml_path = config.get_option(
+                'System', 'udunits2_xml_path',
+                default=os.path.join(sys.prefix, 'share', 'udunits',
+                                     'udunits2.xml'))
             _ud_system = _ut_read_xml(_alt_xml_path.encode())
     if not _ud_system:
         _status_msg = 'UNKNOWN'
